@@ -30,7 +30,7 @@ async def run():
 
         parser = Parser(args.input, session) # type: ignore
         intermediate = await parser.parse()
-        read_config_into(args.config, intermediate)
+        read_config_into(args.config, intermediate, not args.ignore_CF_flag)
         await resolve_conflicts(session, intermediate) # type: ignore
 
         for format in args.formats:
